@@ -92,7 +92,7 @@ class Account:
 
         :param: session: MM login session instance,
                 ICC: ICC number of the order-item we need
-        :return: OrderItem object with corresponding ICC
+        :return: most recently created  OrderItem object with corresponding ICC
         """
         params = {"rowsPerPage": 30, "actualPage": 1}
 
@@ -101,15 +101,17 @@ class Account:
         )
         order_item_list = response["rows"]
 
-        order_item = [order_item for order_item in order_item_list
-                      if order_item.get("simAttributes").get("ICCID") == str(ICC)]
+        icc_order_items = [order_item for order_item in order_item_list
+                           if order_item.get("simAttributes").get("ICCID") == str(ICC)]
 
-        if order_item:
-            # There can be just one order-item with a given ICC.
-            # The MM system does not accept a repeated ICC, so it is a unique identifier.
-            return OrderItem(**order_item[0])
-        else:
+        if len(icc_order_items) == 0:
             raise OrderItemNotFoundByICC(ICC, self.id)
+        elif len(icc_order_items) == 1:
+            order_item = icc_order_items[0]
+        else:
+            order_item = self._get_newest_order_item(icc_order_items)
+
+        return OrderItem(**order_item)
 
     def _get_contract_by_phone(self, entity, session, phone):
         """
@@ -156,3 +158,13 @@ class Account:
 
         if len(missing_attributes) != 0:
             raise AccountRequiredParamsError(sorted(missing_attributes))
+
+    def _get_newest_order_item(self, order_items):
+        """
+        From a list of dict formatted order_items, gets the newest one according to their
+        `createdDate`.
+        """
+        sorted_order_items = sorted(order_items,
+                                    key=lambda order_item: order_item.get("createdDate"),
+                                    reverse=True)
+        return sorted_order_items[0]
